aboutsummaryrefslogtreecommitdiff
path: root/src/xz/main.c
diff options
context:
space:
mode:
authorLasse Collin <lasse.collin@tukaani.org>2009-06-26 20:43:36 +0300
committerLasse Collin <lasse.collin@tukaani.org>2009-06-26 20:43:36 +0300
commit5e1257466dcb66f1d7a3f71814a5ad885cba43e8 (patch)
treee624b4266b0edd6ea0d67826ecfca9bab6bba314 /src/xz/main.c
parentUgly hack to make it possible to use the thousand separator (diff)
downloadxz-5e1257466dcb66f1d7a3f71814a5ad885cba43e8.tar.xz
Rename process_file() to coder_run().
Diffstat (limited to '')
-rw-r--r--src/xz/main.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/xz/main.c b/src/xz/main.c
index 8a6cde63..868d2888 100644
--- a/src/xz/main.c
+++ b/src/xz/main.c
@@ -277,7 +277,7 @@ main(int argc, char **argv)
}
// Replace the "-" with a special pointer, which is
// recognized by process_file() and other things.
// This way error messages get a proper filename
// string and the code still knows that it is
// handling the special case of stdin.
@@ -285,7 +285,7 @@ main(int argc, char **argv)
}
// Do the actual compression or uncompression.
- process_file(args.arg_names[i]);
+ coder_run(args.arg_names[i]);
}
// If --files or --files0 was used, process the filenames from the
@@ -301,7 +301,7 @@ main(int argc, char **argv)
// read_name() doesn't return empty names.
assert(name[0] != '\0');
- process_file(name);
+ coder_run(name);
}
if (args.files_name != stdin_filename)
@@ -277,7 +277,7 @@ main(int argc, char **argv)
}
// Replace the "-" with a special pointer, which is
- // recognized by process_file() and other things.
+ // recognized by coder_run() and other things.
// This way error messages get a proper filename
// string and the code still knows that it is